module.exports = defineTest({
	description: 'deshadows function expression ID (#1176)'
});
